# eric7.WebBrowser.Feeds.FeedsDialog

Module implementing a dialog to add RSS feeds.

### Global Attributes

None

### Classes

FeedsDialog | Class implementing a dialog to add RSS feeds.

### Functions

None

## FeedsDialog

Class implementing a dialog to add RSS feeds.

### Derived from

QDialog, Ui_FeedsDialog

### Class Attributes

None

### Class Methods

None

### Methods

FeedsDialog | Constructor
__addFeed | Private slot to add a RSS feed.

### Static Methods

None

#### FeedsDialog (Constructor)

FeedsDialog(availableFeeds, browser, parent=None)

Constructor

availableFeeds (list of [(str, str)])
  list of available RSS feeds
browser (WebBrowserView)
  reference to the browser widget
parent (QWidget)
  reference to the parent widget

#### FeedsDialog.__addFeed

__addFeed(button)

Private slot to add a RSS feed.

button (QPushButton)
  reference to the feed button

Up